% script that illustrates Kalman filter on a simple model;

% close all 
clear all
clc


%% Set filtration range
rng_filt = qq(2010,1):qq(2016,4);

% range for reporting
rng_report = qq(2009,1):qq(2016,4);

%% load and solve the model
m = model('closed_model.model','linear',true);
p = setparam;
m = assign(m,p);

m = solve(m);
m = sstate(m);


%% Create database of observables
dbobs = sstatedb(m,qq(2010,1):qq(2012,4));


%% Baseline
dbobs.obs_dl_cpi(qq(2013,1)) = 4;

% Run Kalman Filter
[~, db_filt] = filter(m,dbobs,rng_filt);

% Report results
report_toy(db_filt,'report_kalman_base.pdf',rng_report)

%% Alternative - more volatile demand shock
dbobs = sstatedb(m,qq(2010,1):qq(2012,4));
dbobs.obs_dl_cpi(qq(2013,1)) = 4;

m2 = alter(m,2);

m2.std_shock_l_y_gap = [1 3];
m2 = solve(m2);
m2 = sstate(m2);


% Run Kalman Filter
[~, db_filt] = filter(m2,dbobs,rng_filt);

% Report results
report_toy(db_filt,'report_kalman_alternative.pdf', rng_report)



